/* 
   COPYRIGHT 2004 KRUPCZAK.ORG, LLC.

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
   USA
 
   For more information, visit:
   http://www.krupczak.org/
*/

/* file - testplugin.c */
/* rdk@krupczak.org */

/* a test plugin */

#ifdef WIN32
#include <windows.h>
#endif

#include <pthread.h>
#include <stdio.h>
#include <sys/types.h>

#ifndef WIN32
#include <unistd.h>
#include <errno.h>
#endif

#include <stdlib.h>

#include "xmp.h"
#include "plugins.h"
#include "xmp_vars.h"
#include "xmp_session.h"
#include "pluginexport.h"

static pthread_t wt;
static int debugLevel = 0;

static int testpluginKill = 0;

static float testpluginVersion = 1.06;
char *versionStr = "KorgVersion 1.06";

/* ************************************************************* */

static void *testplugin_dowork(void *blah)
{
     static char *ptr = NULL;

     printf("testplugin: do work starting\n");

     ptr = (char *)malloc(10);
     if (ptr == NULL) {
        printf("testplugin: dowork malloc failed, %d\n",errno);
     }
     else {
        if (debugLevel)
           printf("testplugin: dowork malloc suceeded\n");

        ptr[0] = 0;
        ptr[1] = 0;

        if (debugLevel)
           printf("testplugin: dowork accessed memory\n");
     }

     while (testpluginKill == 0) {

       if (debugLevel)
          printf("\ttestplugin: worker doing work\n");
#ifdef WIN32
       Sleep(30*1000);
#else
       sleep(30);
#endif
     }

     /* return effectively killing me */

     printf("testplugin_dowork: returning\n");

     return NULL;
}

/* ************************************************************* */

DLLExport int init()
{
     char version[64];
     float v;

     printf("testplugin: init called\n");
     
     debugLevel = xmpGetAgentDebugLevel();

     v = xmpFindBinaryVersion("testplugin-linux.so",NULL);
     sprintf(version,"%3.2f",v);
     xmpAddModule("testplugin-linux.so",version,"testplugin",NULL,2);

     v = xmpFindBinaryVersion("testplugin-solaris.so",NULL);
     sprintf(version,"%3.2f",v);
     xmpAddModule("testplugin-solaris.so",version,"testplugin",NULL,2);

     v = xmpFindBinaryVersion("testplugin-solx86.so",NULL);
     sprintf(version,"%3.2f",v);
     xmpAddModule("testplugin-solx86.so",version,"testplugin",NULL,2);

     v = xmpFindBinaryVersion("testplugin-win32.dll",NULL);
     sprintf(version,"%3.2f",v);
     xmpAddModule("testplugin-win32.dll",version,"testplugin",NULL,2);

     return 1;
}

/* ************************************************************* */

DLLExport int start()
{

     printf("testplugin: start called\n");

     /* start a thread */
     if (pthread_create(&wt,NULL,testplugin_dowork,NULL) < 0) {
        perror("Failed to create worker thread for testplugin");
        return -1;
     }
     pthread_detach(wt);

     return 1;
}

/* ************************************************************* */

DLLExport int modinfo(char *modname, int modnamesz, char *descr, int descrsz)
{
     printf("testplugin: modinfo called\n");

     if ((modname == NULL) || (descr == NULL)) {
        return -1;
     }

     if ((modnamesz < 11) || (descrsz < 30)) {
        return -1;
     }

     /* no commas in plugin description please!!! XXX */
     sprintf(modname,"testPlugin");
     sprintf(descr,"testPlugin version %3.2f",testpluginVersion);

     return 1;
}

/* ************************************************************* */

DLLExport int finish()
{
     printf("testplugin: finish called\n");

     /* need to kill any threads that we started;
        use pthread_kill() to send signal to thread(s)
        running within me and have them exit */

     /* or, use pthread_cancel() to cancel threads
        that are at various cancel points set by
        threads calling pthread_testcancel() */

     /* unload any variables, close files, write data files, etc. */

     /* set kill variable; threads see it and exit */
     testpluginKill = 1;

     return 1;
}

/* ************************************************************* */

#ifdef WIN32

/* a DLL entry point called upon load/free; we dont normally
   need to do anything but some plugins may need this
   level of initialization/uninitialization */

BOOL WINAPI DLLMain(HINSTANCE hDll, DWORD Reason, LPVOID Reserved)
{
     return TRUE;
}

#endif /* WIN32 */

/* ************************************************************* */
