/* 
   COPYRIGHT 2005 KRUPCZAK.ORG, LLC.

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
   USA
 
   For more information, visit:
   http://www.krupczak.org/
*/

/* file - ntsetup.c */
/* rdk@krupczak.org */

/* setup, manage NT service creation/registration */

#ifdef WIN32

#include <windows.h>
#include <stdio.h>
#include <sys/types.h>
#include <string.h>
#include <sys/stat.h>
#include <stdlib.h>

#include "setuplib.h"

int verbose = 0;

/* format of versionStr variable is "KorgVersion<space>%3.2f" 
   that way, our software distribution and updating component
   can correctly figure out version of some distributable
   binary thing */   

char *versionStr = "KorgVersion 1.02";

/* ************************************************************* */

int usage(char *progname)
{
     fprintf(stderr,
             "usage: %s [-h][-v] [-t target] -[list|create|delete|status]\n",
             progname);

     exit(-1);
}

/* ************************************************************* */

/* ************************************************************* */

int main(int argc, char *argv[]) 
{
     int i;
     char *target = NULL;
     WSADATA wsaData;
     int didSomething = 0;

     if (WSAStartup(0x202,&wsaData) == SOCKET_ERROR) {
        perror("WSAStartup failed");
        WSACleanup();
        exit(-1);
     }

     if (argc == 1)
        usage(argv[0]);

     for (i=1; i<argc; i++) {
         if (argv[i][0] == '-') {

	    switch (argv[i][1]) {
	      case 'h':
		 usage(argv[0]);
                 break;
  	      case 'v':
	 	 verbose = 1;
                 break;
	      case 't':
	 	 target = argv[++i];
                 fprintf(stderr,"Targeting system '%s'\n",target);
                 break;

  	      case 'l': /* list */
                 didSomething = 1;
		 listServices(target,1);
                 break;

	      case 'c': /* create service */
                 didSomething = 1;
		 if (createService(target,verbose) > 0)
		    fprintf(stderr,"Service created\n");
                 break;

  	      case 'd': /* remove service */
                 didSomething = 1;
		 if (removeService(target,verbose) > 0) 
		    fprintf(stderr,"Service removed\n");
	 	 break;

	      case 's': /* status/verify */
                 didSomething = 1;
		 if (verifyService(target,verbose) > 0)
		    fprintf(stderr,"Service verified\n");
	  	 break;

            } /* switch */

         } /* if - */

     } /* for */

     if (didSomething == 0)
        usage(argv[0]);

}

/* ************************************************************* */

#endif /* WIN32 */

