/* 
   COPYRIGHT 2005 KRUPCZAK.ORG, LLC.

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
   USA
 
   For more information, visit:
   http://www.krupczak.org/
*/

/* file - xmpd_log.c */
/* rdk@krupczak.org */

/* logging for win32/unix since we cant write to syslog
   nor stdout/stderr as a win32 service */

#ifdef WIN32
#include <windows.h>
#endif

#include <stdio.h>
#include <time.h>
#include <sys/types.h>
#include <stdlib.h>
#ifndef WIN32
#include <syslog.h>
#endif

#include "xmp.h"
#include "globals.h"

/* ************************************************************* */
/* ************************************************************* */
/* ************************************************************* */
/* ************************************************************* */

#ifdef WIN32

/* we should convert logging to varargs like real syslog XXX */
/* for now, just quick and dirty to do some debugging */

static FILE *fp = NULL;

int open_log()
{
     if ((fp = fopen(XMPD_LOGFILE,"a")) == NULL) {
        fprintf(stderr,"failed to open logfile, %d\n",errno);
        return -1;
     }

     return 1;
}

int close_log()
{
     if (fp != NULL)
        fclose(fp);

     return 1;
}

int xmpd_log(char *message)
{
     char timestr[64];
     char *ptr;
     time_t now;

     now = time(NULL);
     ptr = ctime(&now);
     strncpy(timestr,ptr,63);
     timestr[63] = 0;
     if (timestr[strlen(timestr)-1] == '\n')
        timestr[strlen(timestr)-1] = 0;

     if (fp != NULL) {
        fprintf(fp,"%s %s\n",timestr,message);
        fflush(fp);
        return 1;
     }

     return 0;
}

/* ************************************************************* */

#endif /* WIN32 */

/* ************************************************************* */
/* ************************************************************* */
/* ************************************************************* */

#ifndef WIN32

int open_log()
{
     openlog("xmpd",LOG_PID|LOG_NDELAY|LOG_NOWAIT,LOG_DAEMON);
     return 1;
}

int close_log()
{
     closelog();
     return 1;
}

int xmpd_log(char *message)
{
     syslog(LOG_DAEMON|LOG_WARNING,"%s",message);
     return 0;
}

#endif /* !WIN32 */

/* ************************************************************* */
